% Constructor of the map from data to colors.
% Always takes either zero or one argument.  For no arguments, the default
% object is created.  For one argument, the argument may be either an
% object of the same type, in which case the copy is created; or, it may be
% a struct with the following fields representing options.
% Options:
%    range =array with range_min, and range_max, 
%    colormap =color map
%
function retobj = data_colormap (varargin)
    class_name='data_colormap';
    parent=classbase;
    if (nargin == 0)
        self.rmin = [];
        self.rmax = [];
        self.colormap = [];
        self.ncolors = 0;
        self = class(self, class_name, parent);
        retobj = self;
        return;
    elseif (nargin == 1)
        arg = varargin{1};
        if strcmp(class(arg),class_name) % copy constructor.
            retobj = arg;
            return;
        else
            options = varargin{1};
            self.rmin = min(options.range);
            self.rmax = max(options.range);
            self.colormap = hot;
            if (isfield(options,'colormap'))
                self.colormap = options.colormap;
            end
            self.ncolors = length(self.colormap(:,1));
            self = class(self, class_name, parent);
            retobj = self;
            return;
        end
    else
        error('Illegal arguments!');
        return;
    end
    return;
end
