% Constructor of the element matrix class.
% Always takes either zero or one argument.  For no arguments, the default
% object is created.  For one argument, the argument may be either an
% object of the same type, in which case the copy is created; or, it may be
% a struct with the following fields representing options.
% Options:
% eqnums= equation numbers,
% mat = matrix
%
function self = elemat (varargin)
    class_name='elemat';
    parent=classbase;
    if (nargin == 0)
        self.eqnums_row = [];
        self.eqnums_col = [];
        self.mat = [];
        self = class(self,class_name,parent);
        return;
    elseif (nargin == 1)
        arg = varargin{1};
        if strcmp(class(arg),class_name) % copy constructor.
            self = arg;
            return;
        else
            options =varargin{1};
            if isfield(options,'eqnums')
                self.eqnums_row = options.eqnums;
                self.eqnums_col = [];
            else
                self.eqnums_row = options.eqnums_row;
                self.eqnums_col = options.eqnums_col;
            end
            self.mat = options.mat;
            [m,n] = size(self.mat);
            if isempty(self.eqnums_col)
                gn=length(self.eqnums_row);
                if (gn ~= n | gn ~= m | n ~= m )
                    error('Size mismatch!');
                end
            else
                gm=length(self.eqnums_row);
                gn=length(self.eqnums_col);
                if (gn ~= n | gm ~= m)
                    error('Size mismatch!');
                end
            end
            self = class(self,class_name,parent);
            return;
        end
    else
        error('Illegal arguments!');
    end
    return;
end

